@@ -4,7 +4,7 @@ package Dist::Zilla::Plugin::Run::Clean;
 # ABSTRACT: execute a command of the distribution on 'dzil clean'
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.035';
+our $VERSION = '0.036';
 
 use Moose;
 with
@@ -16,7 +16,7 @@ use namespace::autoclean;
 
 {
     use Dist::Zilla::Dist::Builder;
-    my $meta = Dist::Zilla::Dist::Builder->meta;
+    my $meta = Moose::Util::find_meta('Dist::Zilla::Dist::Builder');
     $meta->make_mutable;
     Moose::Util::add_method_modifier($meta, 'after',
         [
@@ -64,7 +64,7 @@ Dist::Zilla::Plugin::Run::Clean - execute a command of the distribution on 'dzil
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
